@@ -26,7 +26,7 @@
 ##  shiela.pl: control program (syntax: Perl)
 ##
 
-my $version = '1.1.2';
+my $version = '1.1.3';
 
 require 5.005;
 
@@ -593,7 +593,7 @@ sub new {
         "Copy-file Updated Created Update-existing Merged Patched Rcs-diff Mode " .
         "Mod-time Removed Remove-entry Set-static-directory Clear-static-directory " .
         "Set-sticky Clear-sticky Template Set-checkin-prog Set-update-prog Notified " .
-        "Module-expansion Wrapper-rcsOption M Mbinary E F MT");
+        "Module-expansion Wrapper-rcsOption M Mbinary E F");
     $cvs->send("UseUnchanged");
     $cvs->send("Root $cvsroot");
     $cvs->send("noop");
